@@ -1,6 +1,6 @@
-# $Id: __init__.py,v 1.12 2004/02/09 09:08:47 wrobell Exp $
+# $Id: __init__.py,v 1.17 2005/05/08 21:08:45 wrobell Exp $
 #
-# Bazaar - an easy to use and powerful abstraction layer between relational
+# Bazaar ORM - an easy to use and powerful abstraction layer between relational
 # database and object oriented application.
 #
 # Copyright (C) 2000-2004 by Artur Wroblewski <wrobell@pld-linux.org>
@@ -21,7 +21,7 @@
 #
 
 """
-Bazaar is an easy to use and powerful abstraction layer between
+Bazaar ORM is an easy to use and powerful abstraction layer between
 relational database and object oriented application.
 
 Features:
@@ -51,17 +51,17 @@ Features:
       association data cache types, etc.
 
 Requirements:
-    - Python 2.3
+    - Python 2.4
     - Python DB API 2.0 module with ``format'' and ``pyformat'' parameter
-      style support (tested with U{psycopg 1.1.10<http://initd.org/software/psycopg>})
-    - RDBMS (tested with U{PostgreSQL 7.4<http://www.postgresql.org>})
+      style support (tested with U{psycopg 2.0<http://initd.org/software/psycopg>})
+    - RDBMS (tested with U{PostgreSQL 8.0<http://www.postgresql.org>})
 
 This is free software distributed under U{GNU Lesser General Public
 License<http://www.gnu.org/licenses/lgpl.html>}. Download it from
 U{project's page<http://savannah.nongnu.org/projects/bazaar/>}
 on U{Savannah<http://savannah.nongnu.org>}.
 
-Bazaar is easy to use, but is designed for people who know both
+Bazaar ORM is easy to use, but is designed for people who know both
 object-oriented and relational technologies, their advantages,
 disadvantages and differences between them (U{``The Object-Relational
 Impedance Mismatch''<http://www.agiledata.org/essays/impedancemismatch.html>} reading
@@ -170,7 +170,7 @@ Now, SQL schema can be created::
 Application code
 ----------------
 
-Application must import Bazaar core module::
+Application must import Bazaar ORM core module::
 
     import bazaar.core
     import psycopg
@@ -179,7 +179,7 @@ DB API module is imported, too. However, it is not obligatory because it can
 be specified in config file, see L{bazaar.config} module documentation for
 details.
 
-Create Bazaar layer instance. There are several parameters
+Create Bazaar ORM layer instance. There are several parameters
 (L{bazaar.core.Bazaar}), but now in this example only list of application
 classes and DB API module are specified::
 
@@ -278,3 +278,43 @@ Finally, commit transaction::
 # Bazaar supports GUI development with set of powerful widgets designed
 # to simplify development of presentation, manipulation and
 # data searching.
+
+class Log(object):
+    """
+    Utility class to deffer creation of loggers (of logging package).
+
+    Usage:
+        log = Log('bazaar.core') # log is Log instance
+        log.debug()              # log is logging.Logger instance
+
+    @ivar logger: Logger name.
+    """
+    def __init__(self, logger):
+        """
+        Create log utility class
+        """
+        self.logger = logger
+
+
+    def __getattr__(self, attr):
+        """
+        Replace log utility instance with real logger from logging package.
+        """
+        import logging
+        import sys
+        log = logging.getLogger(self.logger)
+        # find modules and utility instance names
+        for modname, mod in sys.modules.items():
+            if mod is not None:
+                 vars = [name for name, var in mod.__dict__.items() if var is self]
+                 if vars:
+                     break
+
+        # replace utility instances
+        for name in vars:
+            setattr(mod, name, log)
+
+        # return requested logger's method/attribute
+        return getattr(log, attr)
+
+        # this method should not be called again for object self, now
