@@ -1,7 +1,7 @@
-# $Id: assoc.py,v 1.48 2004/03/29 23:14:15 wrobell Exp $
+# $Id: assoc.py,v 1.52 2005/05/08 15:59:23 wrobell Exp $
 #
-# Bazaar - an easy to use and powerful abstraction layer between relational
-# database and object oriented application.
+# Bazaar ORM - an easy to use and powerful abstraction layer between
+# relational database and object oriented application.
 #
 # Copyright (C) 2000-2004 by Artur Wroblewski <wrobell@pld-linux.org>
 # 
@@ -77,15 +77,12 @@ where::
 
 """
 
-import sets
 import itertools
 import weakref
 
-import logging
-
 import bazaar.exc
 
-log = logging.getLogger('bazaar.assoc')
+log = bazaar.Log('bazaar.assoc')
 
 
 def juggle(obj, value, app, rem):
@@ -104,7 +101,7 @@ def juggle(obj, value, app, rem):
             del rem[obj]
 
     if obj not in app:
-        app[obj] = sets.Set()
+        app[obj] = set()
     app[obj].add(value)
 
     assert value in app[obj]
@@ -281,7 +278,7 @@ class AssociationReferenceProxy(object):
         Create association reference proxy.
 
         Brokers are not initialized with the constructor. Instead, they are
-        set when Bazaar layer is started up.
+        set when Bazaar ORM layer is started up.
 
         @param col: Application object's class attribute.
 
@@ -514,7 +511,7 @@ class List(AssociationReferenceProxy):
                 # when needed
                 keys = self.cache[obj]
             else:
-                keys = sets.Set()
+                keys = set()
                 self.cache[obj] = keys
             keys.add(vkey)
 
@@ -530,7 +527,7 @@ class List(AssociationReferenceProxy):
 
         or to get a set::
 
-            order_item_set = sets.Set(ord.items)
+            order_item_set = set(ord.items)
 
 
         @param obj: Application object.
@@ -600,9 +597,9 @@ class List(AssociationReferenceProxy):
             # loading data now and cache[obj] will be a unwanted recursive call
             keys = self.cache.dicttype.__getitem__(self.cache, obj)
         else:
-            keys = sets.Set()
+            keys = set()
             self.cache[obj] = keys
-        assert isinstance(keys, sets.Set)
+        assert isinstance(keys, set)
         keys.add(vkey)
 
 
@@ -637,8 +634,8 @@ class List(AssociationReferenceProxy):
         # return all objects with defined primary key values
         def getObjects():
             keys = self.cache[obj]
-            if keys is not None:
-                for vkey in list(self.cache[obj]):
+            if keys:
+                for vkey in keys.copy():
                     yield self.vbroker.get(vkey)
         
 
