@@ -1,7 +1,7 @@
-# $Id: conf.py,v 1.32 2004/03/23 13:48:24 wrobell Exp $
+# $Id: conf.py,v 1.34 2005/05/07 00:26:15 wrobell Exp $
 #
-# Bazaar - an easy to use and powerful abstraction layer between relational
-# database and object oriented application.
+# Bazaar ORM - an easy to use and powerful abstraction layer between
+# relational database and object oriented application.
 #
 # Copyright (C) 2000-2004 by Artur Wroblewski <wrobell@pld-linux.org>
 # 
@@ -212,13 +212,11 @@ SQL schema for C{Boss} class relation can look like::
 
 """
 
-import logging
-
 import bazaar.core
 import bazaar.cache
 import bazaar.exc
 
-log = logging.getLogger('bazaar.conf')
+log = bazaar.Log('bazaar.conf')
 
 
 class Column:
