@@ -1,7 +1,7 @@
-# $Id: core.py,v 1.36 2004/05/23 00:24:32 wrobell Exp $
+# $Id: core.py,v 1.40 2005/05/08 16:30:43 wrobell Exp $
 #
-# Bazaar - an easy to use and powerful abstraction layer between relational
-# database and object oriented application.
+# Bazaar ORM - an easy to use and powerful abstraction layer between
+# relational database and object oriented application.
 #
 # Copyright (C) 2000-2004 by Artur Wroblewski <wrobell@pld-linux.org>
 # 
@@ -21,7 +21,7 @@
 #
 
 """
-This module contains basic Bazaar implementation.
+This module contains basic Bazaar ORM implementation.
 
 Every application object should derive from L{PersistentObject} class.
 
@@ -32,14 +32,11 @@ Brokers (L{Broker} class) are responsible for operations on objects of
 specific application class.
 """
 
-import logging
-
 import bazaar.assoc
 import bazaar.cache
 import bazaar.motor
 
-log = logging.getLogger('bazaar.core')
-
+log = bazaar.Log('bazaar.core')
 
 class PersistentObject(object):
     """
@@ -64,7 +61,7 @@ class PersistentObject(object):
 
 
 
-class Broker:
+class Broker(object):
     """
     Application class broker.
 
@@ -92,7 +89,6 @@ class Broker:
         @param cls: Application class.
         @param mtr: Database access object.
         """
-
         self.reload = True
         self.cls = cls
         
@@ -218,7 +214,7 @@ class Broker:
 
 
 
-class Bazaar:
+class Bazaar(object):
     """
     The interface to get, modify, find and perform other tasks on
     application objects.
@@ -234,7 +230,7 @@ class Bazaar:
 
     def __init__(self, cls_list, config = None, dsn = '', dbmod = None, seqpattern = None):
         """
-        Start the Bazaar layer.
+        Start the Bazaar ORM layer.
 
         If database source name is not empty, then database connection is
         created.
@@ -269,7 +265,7 @@ class Bazaar:
 
     def init(self):
         """
-        Initialize the Bazaar layer.
+        Initialize the Bazaar ORM layer.
         """
         self.motor = bazaar.motor.Motor(self.dbmod)
         self.brokers = {}
@@ -360,9 +356,9 @@ class Bazaar:
 
     def parseConfig(self, config): #fixme: debug messages
         """
-        Parse Bazaar configuration.
+        Parse Bazaar ORM configuration.
 
-        @param config: Bazaar configuration.
+        @param config: Bazaar ORM configuration.
 
         @see: L{setConfig} L{bazaar.config.Config} L{bazaar.config.CPConfig}
         """
@@ -429,7 +425,7 @@ class Bazaar:
 
     def setConfig(self, config):
         """
-        Set Bazaar configuration.
+        Set Bazaar ORM configuration.
 
         @see: L{parseConfig} L{init} L{bazaar.config.Config} L{bazaar.config.CPConfig}
         """
@@ -474,6 +470,16 @@ class Bazaar:
         if __debug__: log.debug('database connection is closed')
 
 
+    def get(self, cls, key):
+        """
+        Get object with key.
+
+        @param cls: Application class.
+        @param key: Object key.
+        """
+        return self.brokers[cls].get(key)
+
+
     def getObjects(self, cls):
         """
         Get list of application objects.
