@@ -1,7 +1,7 @@
-# $Id: motor.py,v 1.31 2004/03/29 19:04:14 wrobell Exp $
+# $Id: motor.py,v 1.34 2005/05/08 16:30:43 wrobell Exp $
 #
-# Bazaar - an easy to use and powerful abstraction layer between relational
-# database and object oriented application.
+# Bazaar ORM - an easy to use and powerful abstraction layer between
+# relational database and object oriented application.
 #
 # Copyright (C) 2000-2004 by Artur Wroblewski <wrobell@pld-linux.org>
 # 
@@ -26,11 +26,9 @@ Data convertor and database access classes.
 import bazaar.core   # it is required to check if objects are
                      # PersistentObject class' instances
 
-import logging
+log = bazaar.Log('bazaar.motor')
 
-log = logging.getLogger('bazaar.motor')
-
-class Convertor:
+class Convertor(object):
     """
     Relational and object data convertor.
 
@@ -387,7 +385,7 @@ class Convertor:
 
 
 
-class Motor:
+class Motor(object):
     """
     Database access object.
 
